@@ -98,8 +98,6 @@ echo "curl --location --request GET "https://$CFD/pic.png" --cookie "Cookie: tok
 
 ## Planned Features
 
-* Migrating to cdk v2. If you know a cool workflow how to continuously support v1 and v2 let me know!
-* Support S3 bucket import ootb.
 * Support custom authorizer
 * Leverage Cloudfront Function for cheaper costs
 
@@ -113,6 +111,12 @@ echo "curl --location --request GET "https://$CFD/pic.png" --cookie "Cookie: tok
 * As always to the amazing CDK / Projen Community. Join us on [Slack](https://cdk-dev.slack.com)!
 * [Projen](https://github.com/projen/projen) project and the community around it
 * To you for checking this out. Check me out and perhaps give me feedback https://martinmueller.dev
+
+I love to work on Content Management Open Source projects. A lot from my stuff you can already use on https://github.com/mmuller88 . If you like my work there and my blog posts, please consider supporting me on Patreon:
+
+<a href='https://patreon.com/bePatron?u=29010217' target='_blank'><img height='36' style='border:0px;height:36px;' src='https://raw.githubusercontent.com/mmuller88/mmuller88/main/patreon.png' border='0' alt='Become a Patreon!' /></a>
+
+<a href='https://ko-fi.com/T6T1BR59W' target='_blank'><img height='36' style='border:0px;height:36px;' src='https://cdn.ko-fi.com/cdn/kofi2.png?v=3' border='0' alt='Buy Me a Coffee at ko-fi.com' /></a>
 '''
 import abc
 import builtins
@@ -127,7 +131,7 @@ import typing_extensions
 from ._jsii import *
 
 import aws_cdk.aws_route53
-import aws_cdk.core
+import constructs
 
 
 @jsii.data_type(
@@ -177,13 +181,13 @@ class CustomDomain:
 
 
 class PrivateAssetBucket(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-private-asset-bucket.PrivateAssetBucket",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         user_pool_client_id: builtins.str,
